@@ -36,7 +36,11 @@ def make_integral_moment_dofs(
     # DOFs per dimension
     for dim, moment_data in enumerate([vertices, edges, faces, volumes]):
         if moment_data is not None:
-            IntegralMoment, SubElement, order = moment_data
+            if len(moment_data) == 3:
+                IntegralMoment, SubElement, order = moment_data
+                mapping = None
+            else:
+                IntegralMoment, SubElement, order, mapping = moment_data
             if order >= SubElement.min_order:
                 sub_type = reference.sub_entity_types[dim]
                 if sub_type is not None:
@@ -46,16 +50,23 @@ def make_integral_moment_dofs(
                             sub_type,
                             vertices=[reference.reference_vertices[v] for v in vs])
                         sub_element = SubElement(sub_ref, order, variant=variant)
-                        for f, d in zip(
-                            sub_element.get_basis_functions(), sub_element.dofs
-                        ):
-                            dofs.append(IntegralMoment(sub_ref, f, d, entity=(dim, i)))
+                        for dn, d in enumerate(sub_element.dofs):
+                            f = sub_element.get_basis_function(dn)
+                            if mapping is None:
+                                dofs.append(IntegralMoment(sub_ref, f, d, entity=(dim, i)))
+                            else:
+                                dofs.append(IntegralMoment(sub_ref, f, d, entity=(dim, i),
+                                                           mapping=mapping))
 
     # DOFs per codimension
     for _dim, moment_data in enumerate([peaks, ridges, facets, cells]):
         dim = reference.tdim - 3 + _dim
         if moment_data is not None:
-            IntegralMoment, SubElement, order = moment_data
+            if len(moment_data) == 3:
+                IntegralMoment, SubElement, order = moment_data
+                mapping = None
+            else:
+                IntegralMoment, SubElement, order, mapping = moment_data
             if order >= SubElement.min_order:
                 sub_type = reference.sub_entity_types[dim]
                 if sub_type is not None:
@@ -65,9 +76,12 @@ def make_integral_moment_dofs(
                             sub_type,
                             vertices=[reference.reference_vertices[v] for v in vs])
                         sub_element = SubElement(sub_ref, order, variant=variant)
-                        for f, d in zip(
-                            sub_element.get_basis_functions(), sub_element.dofs
-                        ):
-                            dofs.append(IntegralMoment(sub_ref, f, d, entity=(dim, i)))
+                        for dn, d in enumerate(sub_element.dofs):
+                            f = sub_element.get_basis_function(dn)
+                            if mapping is None:
+                                dofs.append(IntegralMoment(sub_ref, f, d, entity=(dim, i)))
+                            else:
+                                dofs.append(IntegralMoment(sub_ref, f, d, entity=(dim, i),
+                                                           mapping=mapping))
 
     return dofs
