@@ -4,7 +4,7 @@ This element's definition appears in https://doi.org/10.1007/BF01389710
 (Brezzi, Douglas, Marini, 1985)
 """
 
-from ..core.finite_element import FiniteElement
+from ..core.finite_element import CiarletElement
 from ..core.moments import make_integral_moment_dofs
 from ..core.polynomials import polynomial_set
 from ..core.functionals import NormalIntegralMoment, IntegralMoment
@@ -12,7 +12,7 @@ from .lagrange import DiscontinuousLagrange
 from .nedelec import NedelecFirstKind
 
 
-class BDM(FiniteElement):
+class BDM(CiarletElement):
     """Brezzi-Douglas-Marini Hdiv finite element."""
 
     def __init__(self, reference, order, variant):
@@ -30,5 +30,4 @@ class BDM(FiniteElement):
     names = ["Brezzi-Douglas-Marini", "BDM", "N2div"]
     references = ["triangle", "tetrahedron"]
     min_order = 1
-    mapping = "contravariant"
     continuity = "H(div)"
