@@ -6,10 +6,10 @@ These elements' definitions appear in https://doi.org/10.1016/j.crma.2004.12.022
 
 import sympy
 from ..core.symbolic import sym_sum, PiecewiseFunction
-from ..core.finite_element import FiniteElement
+from ..core.finite_element import CiarletElement
 
 
-class DualFiniteElement(FiniteElement):
+class DualCiarletElement(CiarletElement):
     """Abstract barycentric finite element."""
 
     def __init__(self, dual_coefficients, fine_space, reference, order, basis,
@@ -54,12 +54,8 @@ class DualFiniteElement(FiniteElement):
                 self._basis_functions.append(PiecewiseFunction(pieces))
         return self._basis_functions
 
-    def map_to_cell(self, f, vertices):
-        """Map a function onto a cell using the appropriate mapping for the element."""
-        raise NotImplementedError()
 
-
-class Dual(DualFiniteElement):
+class Dual(DualCiarletElement):
     """Barycentric dual finite element."""
 
     def __init__(self, reference, order, variant):
@@ -98,10 +94,9 @@ class Dual(DualFiniteElement):
     min_order = 0
     max_order = 1
     continuity = "C0"
-    mapping = "identity"
 
 
-class BuffaChristiansen(DualFiniteElement):
+class BuffaChristiansen(DualCiarletElement):
     """Buffa-Christiansen barycentric dual finite element."""
 
     def __init__(self, reference, order, variant):
@@ -129,10 +124,9 @@ class BuffaChristiansen(DualFiniteElement):
     min_order = 1
     max_order = 1
     continuity = "H(div)"
-    mapping = "contravariant"
 
 
-class RotatedBuffaChristiansen(DualFiniteElement):
+class RotatedBuffaChristiansen(DualCiarletElement):
     """RotatedBuffa-Christiansen barycentric dual finite element."""
 
     def __init__(self, reference, order, variant):
@@ -160,4 +154,3 @@ class RotatedBuffaChristiansen(DualFiniteElement):
     min_order = 1
     max_order = 1
     continuity = "H(div)"
-    mapping = "contravariant"
