@@ -5,14 +5,14 @@ This element's definition appears in https://doi.org/10.2307/2006147
 """
 
 import sympy
-from ..core.finite_element import FiniteElement
+from ..core.finite_element import CiarletElement
 from ..core.functionals import (PointEvaluation, PointNormalDerivativeEvaluation,
                                 DerivativePointEvaluation)
-from ..core.symbolic import sym_sum, PiecewiseFunction, zero, x, subs
+from ..core.symbolic import sym_sum, PiecewiseFunction, zero
 from .hermite import Hermite
 
 
-class HsiehCloughTocher(FiniteElement):
+class HsiehCloughTocher(CiarletElement):
     """Hsieh-Clough-Tocher finite element."""
 
     def __init__(self, reference, order, variant):
@@ -71,24 +71,8 @@ class HsiehCloughTocher(FiniteElement):
             reference, order, poly, dofs, reference.tdim, 1
         )
 
-    def perform_mapping(self, basis, map, inverse_map):
-        """Map the basis onto a cell using the appropriate mapping for the element."""
-        out = []
-        tdim = self.reference.tdim
-        J = sympy.Matrix([[map[i].diff(x[j]) for j in range(tdim)] for i in range(tdim)])
-        for v in range(tdim + 1):
-            out.append(basis[(tdim + 1) * v])
-            for i in range(tdim):
-                out.append(sym_sum(a * b for a, b in
-                                   zip(basis[(tdim + 1) * v + 1: (tdim + 1) * (v + 1)],
-                                       J.row(i))))
-        out += basis[-3:]
-        assert len(out) == len(basis)
-        return [subs(b, x, inverse_map) for b in out]
-
     names = ["Hsieh-Clough-Tocher", "Clough-Tocher", "HCT", "CT"]
     references = ["triangle"]
     min_order = 3
     max_order = 3
-    mapping = "identity"
     continuity = "C1"
