@@ -3,17 +3,16 @@
 import sympy
 from itertools import product
 from ..core.symbolic import one, zero
-from ..core.finite_element import FiniteElement
+from ..core.finite_element import CiarletElement
 from ..core.polynomials import polynomial_set
 from ..core.functionals import PointEvaluation, DotPointEvaluation
 from ..core.quadrature import get_quadrature
 
 
-class Lagrange(FiniteElement):
+class Lagrange(CiarletElement):
     """Lagrange finite element."""
 
     def __init__(self, reference, order, variant):
-        from symfem import create_reference
         if order == 0:
             dofs = [
                 PointEvaluation(
@@ -31,10 +30,8 @@ class Lagrange(FiniteElement):
             for v_n, v in enumerate(reference.reference_vertices):
                 dofs.append(PointEvaluation(v, entity=(0, v_n)))
             for edim in range(1, 4):
-                for e_n, vs in enumerate(reference.sub_entities(edim)):
-                    entity = create_reference(
-                        reference.sub_entity_types[edim],
-                        vertices=tuple(reference.reference_vertices[i] for i in vs))
+                for e_n in range(reference.sub_entity_count(edim)):
+                    entity = reference.sub_entity(edim, e_n)
                     for i in product(range(1, order), repeat=edim):
                         if sum(i) < order:
                             dofs.append(
@@ -52,10 +49,9 @@ class Lagrange(FiniteElement):
     references = ["interval", "triangle", "tetrahedron"]
     min_order = 0
     continuity = "C0"
-    mapping = "identity"
 
 
-class DiscontinuousLagrange(FiniteElement):
+class DiscontinuousLagrange(CiarletElement):
     """Discontinuous Lagrange finite element."""
 
     def __init__(self, reference, order, variant):
@@ -81,10 +77,9 @@ class DiscontinuousLagrange(FiniteElement):
     references = ["interval", "triangle", "tetrahedron", "quadrilateral", "hexahedron"]
     min_order = 0
     continuity = "L2"
-    mapping = "identity"
 
 
-class VectorLagrange(FiniteElement):
+class VectorLagrange(CiarletElement):
     """Vector Lagrange finite element."""
 
     def __init__(self, reference, order, variant):
@@ -113,10 +108,9 @@ class VectorLagrange(FiniteElement):
     references = ["interval", "triangle", "tetrahedron"]
     min_order = 0
     continuity = "C0"
-    mapping = "identity"
 
 
-class VectorDiscontinuousLagrange(FiniteElement):
+class VectorDiscontinuousLagrange(CiarletElement):
     """Vector Lagrange finite element."""
 
     def __init__(self, reference, order, variant):
@@ -145,10 +139,9 @@ class VectorDiscontinuousLagrange(FiniteElement):
     references = ["interval", "triangle", "tetrahedron", "quadrilateral", "hexahedron"]
     min_order = 0
     continuity = "L2"
-    mapping = "identity"
 
 
-class MatrixDiscontinuousLagrange(FiniteElement):
+class MatrixDiscontinuousLagrange(CiarletElement):
     """Matrix Lagrange finite element."""
 
     def __init__(self, reference, order, variant):
@@ -178,10 +171,9 @@ class MatrixDiscontinuousLagrange(FiniteElement):
     references = ["triangle", "tetrahedron", "quadrilateral", "hexahedron"]
     min_order = 0
     continuity = "L2"
-    mapping = "identity"
 
 
-class SymmetricMatrixDiscontinuousLagrange(FiniteElement):
+class SymmetricMatrixDiscontinuousLagrange(CiarletElement):
     """Symmetric matrix Lagrange finite element."""
 
     def __init__(self, reference, order, variant):
@@ -222,4 +214,3 @@ class SymmetricMatrixDiscontinuousLagrange(FiniteElement):
     references = ["triangle", "tetrahedron", "quadrilateral", "hexahedron"]
     min_order = 0
     continuity = "L2"
-    mapping = "identity"
