@@ -4,13 +4,13 @@ This element's definition appears in https://doi.org/10.1017/S0001925900004546
 (Morley, 1968)
 """
 
-from ..core.finite_element import FiniteElement
+from ..core.finite_element import CiarletElement
 from ..core.polynomials import polynomial_set
 from ..core.functionals import PointEvaluation, PointNormalDerivativeEvaluation
 from ..core.symbolic import sym_sum
 
 
-class Morley(FiniteElement):
+class Morley(CiarletElement):
     """Morley finite element."""
 
     def __init__(self, reference, order, variant):
@@ -37,5 +37,4 @@ class Morley(FiniteElement):
     references = ["triangle"]
     min_order = 2
     max_order = 2
-    mapping = "identity"
     continuity = "L2"
