@@ -5,7 +5,7 @@ This element's definition appears in https://doi.org/10.1137/S0036142901383910
 and https://doi.org/10.1007/s10092-006-0124-6 (Tail, Mardal, 2006)
 """
 
-from ..core.finite_element import FiniteElement
+from ..core.finite_element import CiarletElement
 from ..core.moments import make_integral_moment_dofs
 from ..core.polynomials import polynomial_set
 from ..core.symbolic import x, zero, one
@@ -15,14 +15,15 @@ from .lagrange import DiscontinuousLagrange
 from .nedelec import NedelecFirstKind
 
 
-class MardalTaiWinther(FiniteElement):
+class MardalTaiWinther(CiarletElement):
     """Mardal-Tai-Winther Hdiv finite element."""
 
     def __init__(self, reference, order, variant):
         assert order == 3
 
         dofs = make_integral_moment_dofs(
-            reference, facets=(NormalIntegralMoment, DiscontinuousLagrange, 1),
+            reference, facets=(NormalIntegralMoment, DiscontinuousLagrange, 1,
+                               "contravariant"),
             variant=variant)
 
         if reference.name == "triangle":
@@ -38,7 +39,8 @@ class MardalTaiWinther(FiniteElement):
                     (2 * x[0] ** 2 * x[1] + x[0] ** 2 + 3 * x[0] * x[1] ** 2,
                      -2 * x[0] * x[1] ** 2 - 2 * x[0] * x[1] - x[1] ** 3)]
             dofs += make_integral_moment_dofs(
-                reference, facets=(TangentIntegralMoment, DiscontinuousLagrange, 0),
+                reference, facets=(TangentIntegralMoment, DiscontinuousLagrange, 0,
+                                   "contravariant"),
                 variant=variant)
         else:
             assert reference.name == "tetrahedron"
@@ -49,7 +51,7 @@ class MardalTaiWinther(FiniteElement):
                                        for i in p)))
 
             dofs += make_integral_moment_dofs(
-                reference, facets=(IntegralMoment, NedelecFirstKind, 1),
+                reference, facets=(IntegralMoment, NedelecFirstKind, 1, "contravariant"),
                 variant=variant)
 
         super().__init__(reference, order, poly, dofs, reference.tdim, reference.tdim)
@@ -58,5 +60,4 @@ class MardalTaiWinther(FiniteElement):
     references = ["triangle", "tetrahedron"]
     min_order = 3
     max_order = 3
-    mapping = "contravariant"
     continuity = "H(div)"
