@@ -4,7 +4,7 @@ These elements' definitions appear in https://doi.org/10.1007/BF01396415
 (Nedelec, 1980) and https://doi.org/10.1007/BF01389668 (Nedelec, 1986)
 """
 
-from ..core.finite_element import FiniteElement
+from ..core.finite_element import CiarletElement
 from ..core.moments import make_integral_moment_dofs
 from ..core.polynomials import polynomial_set, Hcurl_polynomials
 from ..core.functionals import TangentIntegralMoment, IntegralMoment
@@ -12,7 +12,7 @@ from .lagrange import DiscontinuousLagrange, VectorDiscontinuousLagrange
 from .rt import RaviartThomas
 
 
-class NedelecFirstKind(FiniteElement):
+class NedelecFirstKind(CiarletElement):
     """Nedelec first kind Hcurl finite element."""
 
     def __init__(self, reference, order, variant):
@@ -21,8 +21,8 @@ class NedelecFirstKind(FiniteElement):
         dofs = make_integral_moment_dofs(
             reference,
             edges=(TangentIntegralMoment, DiscontinuousLagrange, order - 1),
-            faces=(IntegralMoment, VectorDiscontinuousLagrange, order - 2),
-            volumes=(IntegralMoment, VectorDiscontinuousLagrange, order - 3),
+            faces=(IntegralMoment, VectorDiscontinuousLagrange, order - 2, "covariant"),
+            volumes=(IntegralMoment, VectorDiscontinuousLagrange, order - 3, "covariant"),
             variant=variant
         )
 
@@ -31,11 +31,10 @@ class NedelecFirstKind(FiniteElement):
     names = ["Nedelec", "Nedelec1", "N1curl"]
     references = ["triangle", "tetrahedron"]
     min_order = 1
-    mapping = "covariant"
     continuity = "H(curl)"
 
 
-class NedelecSecondKind(FiniteElement):
+class NedelecSecondKind(CiarletElement):
     """Nedelec second kind Hcurl finite element."""
 
     def __init__(self, reference, order, variant):
@@ -44,8 +43,8 @@ class NedelecSecondKind(FiniteElement):
         dofs = make_integral_moment_dofs(
             reference,
             edges=(TangentIntegralMoment, DiscontinuousLagrange, order),
-            faces=(IntegralMoment, RaviartThomas, order - 1),
-            volumes=(IntegralMoment, RaviartThomas, order - 2),
+            faces=(IntegralMoment, RaviartThomas, order - 1, "covariant"),
+            volumes=(IntegralMoment, RaviartThomas, order - 2, "covariant"),
             variant=variant
         )
 
@@ -54,5 +53,4 @@ class NedelecSecondKind(FiniteElement):
     names = ["Nedelec2", "N2curl"]
     references = ["triangle", "tetrahedron"]
     min_order = 1
-    mapping = "covariant"
     continuity = "H(curl)"
