@@ -3,7 +3,7 @@
 import sympy
 from itertools import product
 from ..core.symbolic import one, zero
-from ..core.finite_element import FiniteElement
+from ..core.finite_element import CiarletElement
 from ..core.moments import make_integral_moment_dofs
 from ..core.polynomials import quolynomial_set, Hdiv_quolynomials, Hcurl_quolynomials
 from ..core.quadrature import get_quadrature
@@ -11,7 +11,7 @@ from ..core.functionals import (PointEvaluation, DotPointEvaluation, IntegralMom
                                 TangentIntegralMoment, NormalIntegralMoment)
 
 
-class Q(FiniteElement):
+class Q(CiarletElement):
     """A Q element."""
 
     def __init__(self, reference, order, variant):
@@ -51,11 +51,10 @@ class Q(FiniteElement):
     names = ["Q"]
     references = ["interval", "quadrilateral", "hexahedron"]
     min_order = 0
-    mapping = "identity"
     continuity = "C0"
 
 
-class DiscontinuousQ(FiniteElement):
+class DiscontinuousQ(CiarletElement):
     """A dQ element."""
 
     def __init__(self, reference, order, variant):
@@ -82,11 +81,10 @@ class DiscontinuousQ(FiniteElement):
     names = ["dQ"]
     references = ["interval", "quadrilateral", "hexahedron"]
     min_order = 0
-    mapping = "identity"
     continuity = "L2"
 
 
-class VectorQ(FiniteElement):
+class VectorQ(CiarletElement):
     """A vector Q element."""
 
     def __init__(self, reference, order, variant):
@@ -114,11 +112,10 @@ class VectorQ(FiniteElement):
     names = ["vector Q", "vQ"]
     references = ["quadrilateral", "hexahedron"]
     min_order = 0
-    mapping = "identity"
     continuity = "C0"
 
 
-class Nedelec(FiniteElement):
+class Nedelec(CiarletElement):
     """Nedelec Hcurl finite element."""
 
     def __init__(self, reference, order, variant):
@@ -128,8 +125,8 @@ class Nedelec(FiniteElement):
         dofs = make_integral_moment_dofs(
             reference,
             edges=(TangentIntegralMoment, DiscontinuousQ, order - 1),
-            faces=(IntegralMoment, RaviartThomas, order - 1),
-            volumes=(IntegralMoment, RaviartThomas, order - 1),
+            faces=(IntegralMoment, RaviartThomas, order - 1, "covariant"),
+            volumes=(IntegralMoment, RaviartThomas, order - 1, "covariant"),
             variant=variant
         )
 
@@ -138,11 +135,10 @@ class Nedelec(FiniteElement):
     names = ["NCE", "RTCE", "Qcurl"]
     references = ["quadrilateral", "hexahedron"]
     min_order = 1
-    mapping = "covariant"
     continuity = "H(curl)"
 
 
-class RaviartThomas(FiniteElement):
+class RaviartThomas(CiarletElement):
     """Raviart-Thomas Hdiv finite element."""
 
     def __init__(self, reference, order, variant):
@@ -152,7 +148,7 @@ class RaviartThomas(FiniteElement):
         dofs = make_integral_moment_dofs(
             reference,
             facets=(NormalIntegralMoment, DiscontinuousQ, order - 1),
-            cells=(IntegralMoment, Nedelec, order - 1),
+            cells=(IntegralMoment, Nedelec, order - 1, "contravariant"),
             variant=variant
         )
 
@@ -161,5 +157,4 @@ class RaviartThomas(FiniteElement):
     names = ["NCF", "RTCF", "Qdiv"]
     references = ["quadrilateral", "hexahedron"]
     min_order = 1
-    mapping = "contravariant"
     continuity = "H(div)"
