@@ -7,12 +7,12 @@ This element's definition appears in https://doi.org/10.1007/BF02733251
 
 import sympy
 from itertools import product
-from ..core.finite_element import FiniteElement
+from ..core.finite_element import CiarletElement
 from ..core.polynomials import polynomial_set
 from ..core.functionals import PointInnerProduct
 
 
-class Regge(FiniteElement):
+class Regge(CiarletElement):
     """A Regge element."""
 
     def __init__(self, reference, order, variant):
@@ -40,7 +40,7 @@ class Regge(FiniteElement):
                                 tuple(o + sum(sympy.Rational(a[j] * b, order + 2)
                                               for a, b in zip(entity.axes, i[::-1]))
                                       for j, o in enumerate(entity.origin)),
-                                tangent, tangent, entity=(edim, e_n)))
+                                tangent, tangent, entity=(edim, e_n), mapping="double_covariant"))
 
         super().__init__(reference, order, poly, dofs, reference.tdim, reference.tdim ** 2,
                          (reference.tdim, reference.tdim))
@@ -48,5 +48,4 @@ class Regge(FiniteElement):
     names = ["Regge"]
     references = ["triangle", "tetrahedron"]
     min_order = 0
-    mapping = "double_covariant"
     continuity = "inner H(curl)"
