@@ -5,13 +5,13 @@ This element's definition appears in https://doi.org/10.2307/2006147
 """
 
 import sympy
-from ..core.finite_element import FiniteElement
+from ..core.finite_element import CiarletElement
 from ..core.functionals import PointEvaluation, DerivativePointEvaluation
 from ..core.polynomials import polynomial_set
-from ..core.symbolic import sym_sum, PiecewiseFunction, zero, x, subs, one
+from ..core.symbolic import PiecewiseFunction, zero, x, one
 
 
-class P1Hermite(FiniteElement):
+class P1Hermite(CiarletElement):
     """P1Hermite finite element."""
 
     def __init__(self, reference, order, variant, poly):
@@ -26,24 +26,6 @@ class P1Hermite(FiniteElement):
             reference, order, poly, dofs, reference.tdim, 1
         )
 
-    def perform_mapping(self, basis, map, inverse_map):
-        """Map the basis onto a cell using the appropriate mapping for the element."""
-        out = []
-        tdim = self.reference.tdim
-        J = sympy.Matrix([[map[i].diff(x[j]) for j in range(tdim)] for i in range(tdim)])
-        for v in range(tdim + 1):
-            out.append(basis[(tdim + 1) * v])
-            for i in range(tdim):
-                out.append(sym_sum(a * b for a, b in
-                                   zip(basis[(tdim + 1) * v + 1: (tdim + 1) * (v + 1)],
-                                       J.row(i))))
-        if tdim == 2:
-            out.append(basis[-1])
-        if tdim == 3:
-            out += basis[-4:]
-        assert len(out) == len(basis)
-        return [subs(b, x, inverse_map) for b in out]
-
     names = []
     references = ["triangle"]
     min_order = 3
@@ -51,7 +33,7 @@ class P1Hermite(FiniteElement):
     continuity = "C0"
 
 
-class ReducedHsiehCloughTocher(FiniteElement):
+class ReducedHsiehCloughTocher(CiarletElement):
     """Reduced Hsieh-Clough-Tocher finite element."""
 
     def __init__(self, reference, order, variant):
@@ -84,10 +66,8 @@ class ReducedHsiehCloughTocher(FiniteElement):
                     x[0] ** 3 - x[1] ** 3, x[0] ** 3 + 3 * x[0] * x[1] ** 2]
         polys[2].remove(x[0] * x[1] ** 2)
 
-        bases = [
-            P1Hermite(r, 3, variant, p).get_basis_functions()
-            for r, p in zip(refs, polys)
-        ]
+        bases = [P1Hermite(r, 3, variant, p).get_basis_functions()
+                 for r, p in zip(refs, polys)]
 
         piece_list = []
         piece_list.append((bases[0][0], zero, bases[2][3]))
@@ -113,23 +93,8 @@ class ReducedHsiehCloughTocher(FiniteElement):
             reference, order, poly, dofs, reference.tdim, 1
         )
 
-    def perform_mapping(self, basis, map, inverse_map):
-        """Map the basis onto a cell using the appropriate mapping for the element."""
-        out = []
-        tdim = self.reference.tdim
-        J = sympy.Matrix([[map[i].diff(x[j]) for j in range(tdim)] for i in range(tdim)])
-        for v in range(tdim + 1):
-            out.append(basis[(tdim + 1) * v])
-            for i in range(tdim):
-                out.append(sym_sum(a * b for a, b in
-                                   zip(basis[(tdim + 1) * v + 1: (tdim + 1) * (v + 1)],
-                                       J.row(i))))
-        assert len(out) == len(basis)
-        return [subs(b, x, inverse_map) for b in out]
-
     names = ["reduced Hsieh-Clough-Tocher", "rHCT"]
     references = ["triangle"]
     min_order = 3
     max_order = 3
-    mapping = "identity"
     continuity = "C1"
