@@ -4,7 +4,7 @@ This element's definition appears in https://doi.org/10.1007/s10208-011-9087-3
 (Arnold, Awanou, 2011)
 """
 
-from ..core.finite_element import FiniteElement
+from ..core.finite_element import CiarletElement
 from ..core.moments import make_integral_moment_dofs
 from ..core.polynomials import (serendipity_set, polynomial_set,
                                 Hdiv_serendipity, Hcurl_serendipity)
@@ -13,7 +13,7 @@ from ..core.functionals import (
 from .lagrange import DiscontinuousLagrange, VectorDiscontinuousLagrange
 
 
-class Serendipity(FiniteElement):
+class Serendipity(CiarletElement):
     """A serendipity element."""
 
     def __init__(self, reference, order, variant):
@@ -36,11 +36,10 @@ class Serendipity(FiniteElement):
     names = ["serendipity", "S"]
     references = ["interval", "quadrilateral", "hexahedron"]
     min_order = 1
-    mapping = "identity"
     continuity = "C0"
 
 
-class SerendipityCurl(FiniteElement):
+class SerendipityCurl(CiarletElement):
     """A serendipity Hcurl element."""
 
     def __init__(self, reference, order, variant):
@@ -50,8 +49,8 @@ class SerendipityCurl(FiniteElement):
         dofs = make_integral_moment_dofs(
             reference,
             edges=(TangentIntegralMoment, DiscontinuousLagrange, order),
-            faces=(IntegralMoment, VectorDiscontinuousLagrange, order - 2),
-            volumes=(IntegralMoment, VectorDiscontinuousLagrange, order - 4),
+            faces=(IntegralMoment, VectorDiscontinuousLagrange, order - 2, "covariant"),
+            volumes=(IntegralMoment, VectorDiscontinuousLagrange, order - 4, "covariant"),
             variant=variant
         )
 
@@ -60,12 +59,10 @@ class SerendipityCurl(FiniteElement):
     names = ["serendipity Hcurl", "Scurl", "BDMCE", "AAE"]
     references = ["quadrilateral", "hexahedron"]
     min_order = 1
-    max_order = 3  # TODO: generalise polynomial set for hexahedra, then remove this
-    mapping = "covariant"
     continuity = "H(curl)"
 
 
-class SerendipityDiv(FiniteElement):
+class SerendipityDiv(CiarletElement):
     """A serendipity Hdiv element."""
 
     def __init__(self, reference, order, variant):
@@ -75,7 +72,7 @@ class SerendipityDiv(FiniteElement):
         dofs = make_integral_moment_dofs(
             reference,
             facets=(NormalIntegralMoment, DiscontinuousLagrange, order),
-            cells=(IntegralMoment, VectorDiscontinuousLagrange, order - 2),
+            cells=(IntegralMoment, VectorDiscontinuousLagrange, order - 2, "contravariant"),
             variant=variant
         )
 
@@ -84,6 +81,4 @@ class SerendipityDiv(FiniteElement):
     names = ["serendipity Hdiv", "Sdiv", "BDMCF", "AAF"]
     references = ["quadrilateral", "hexahedron"]
     min_order = 1
-    max_order = 3  # TODO: generalise polynomial set for hexahedra, then remove this
-    mapping = "contravariant"
     continuity = "H(div)"
