@@ -1,6 +1,6 @@
 """Taylor element on an interval, triangle or tetrahedron."""
 
-from ..core.finite_element import FiniteElement
+from ..core.finite_element import CiarletElement
 from ..core.moments import make_integral_moment_dofs
 from ..core.polynomials import polynomial_set
 from ..core.functionals import IntegralMoment, DerivativePointEvaluation
@@ -9,8 +9,8 @@ from .lagrange import DiscontinuousLagrange
 from itertools import product
 
 
-class Bell(FiniteElement):
-    """Bell finite element."""
+class Taylor(CiarletElement):
+    """Taylor finite element."""
 
     def __init__(self, reference, order, variant):
         dofs = make_integral_moment_dofs(
@@ -23,7 +23,6 @@ class Bell(FiniteElement):
                 dofs.append(DerivativePointEvaluation(midpoint, i, entity=(reference.tdim, 0)))
 
         poly = polynomial_set(reference.tdim, 1, order)
-        print(len(dofs), len(poly))
 
         super().__init__(reference, order, poly, dofs, reference.tdim, 1)
 
@@ -31,4 +30,3 @@ class Bell(FiniteElement):
     references = ["interval", "triangle", "tetrahedron"]
     min_order = 0
     continuity = "L2"
-    mapping = "identity"
